Linear regression model that compares hospitals and population in a given US county
Source:R/data.R
us_atc_model.RdLinear regression model that compares hospitals and population in a given US county
R/data.R
us_atc_model.RdLinear regression model that compares hospitals and population in a given US county