A manually created list of 'x' and 'y' coordinates to place the hexagons representing each state in the USA. These are relative positions from each of the other states.
A manually created list of 'x' and 'y' coordinates to place the hexagons representing each state in the USA. These are relative positions from each of the other states.