List of the largest cities in a given state.
Format
A tibble with 7 variables and 1,005 rows:
- city_name
Name of the city
- state
Two letter state abbreviation
- population
Population count estimate for 2015
- capital
2 for capital of the state, 0 for not
- x
Map location used a converted number from the city's longitude
- y
Map location used a converted number from the city's latitude
- position
Rank within the state based on the population number