A list of the 50 states, and District of Columbia. It contains the number of hospitals and population per state.
Format
A tibble with 6 variables and 51 rows:
- state
Two letter state abbreviation
- hospitals
Number of hospitals inside the county
- population
Population count estimate for 2015
- per_person
Population divided by the number of hospitals in the state
- per_person_quartile
Quartile for per_person variable
- state_name
Name of the state