A convenience function that simplifies the creation of the manifest file needed for publication.
write_manifest(
folder_location,
primary_document = NULL,
ignore_files = list("config.yml", ".gitignore", "manifest.json", ".DS_Store",
".gitignore"),
silent = FALSE
)The folder containing the files of a single asset to be published
An optional argument. If passed, the function will use that as the name of the primary document
A list of files to be disregarded when creating the manifest file.
To run with or without console updates